#!/usr/bin/env python3

'''
Criticality: Normal
Checks that the webserver is running.
'''

from pathlib import Path
import re
import requests
import sys

sys.path.append(str(Path(__file__).parents[1].resolve()))

# pylint: disable=wrong-import-position
from utilities import logging as lg  # noqa: E402


def main():
    lg.log('Checking nginx status:')

    stats_file = Path('/etc/nginx/sites-enabled/stats.conf')
    if not stats_file.exists():
        lg.info('The Nginx status vhost does not exist, skipping test.')
        return 2

    with open(stats_file, 'r') as fo:
        content = fo.read()
    listen_s = re.search(r'listen (\d+);', content)
    if not listen_s:
        lg.info('The Nginx status vhost has no listen directive, skipping test.')
        return 2
    port = int(listen_s.group(1))

    try:
        req = requests.get(
            'http://127.0.0.1:%s/nginx_status' % port,
            proxies={'http': '', 'https': ''},
            timeout=5,
        )
        if req.status_code != 200:
            raise Exception('Status code: %s.' % req.status_code)
        if 'Active connections' not in req.text:
            raise Exception('invalid response from nginx status url.')
    except Exception as e:
        lg.error(str(e))
        return 1

    lg.success('Status code: %s.' % req.status_code)
    return 0


if __name__ == '__main__':
    rc = main()
    sys.exit(rc)
