#!/usr/bin/env python3

'''
EnvSetup systemd handler.
'''

import os
import subprocess

from .config import get_conf


def check_systemd_setup():
    '''
    Add envsetup timer and service and enable them if enabled in configuration.
    Confiugration key is TESTER_ENABLE_SYSTEMD_TIMER.
    '''
    # Write systemd files if needed
    template_dir = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))), 'systemd')
    files_to_write = (
        ('/lib/systemd/system/envsetup-tester.service', os.path.join(template_dir, 'envsetup-tester.service')),
        ('/lib/systemd/system/envsetup-tester.timer', os.path.join(template_dir, 'envsetup-tester.timer')),
    )
    for path, template in files_to_write:
        content = ''
        if os.path.exists(path):
            with open(path, 'r') as fo:
                content = fo.read()
        with open(template, 'r') as fo:
            expected = fo.read()
        if not content or content != expected:
            # Replace file if different
            with open(path, 'w') as fo:
                fo.write(expected)
            print('File "%s" updated.' % path)
        else:
            print('File "%s" is already up to date.' % path)

    # Enable systemd timer if needed
    if get_conf('TESTER_ENABLE_SYSTEMD_TIMER') == '1':
        print('Checking status of envsetup systemd timer...')
        p = subprocess.run(['systemctl', 'is-enabled', 'envsetup-tester.timer'])
        if p.returncode != 0:
            subprocess.run(['systemctl', 'enable', 'envsetup-tester.timer'])
            subprocess.run(['systemctl', 'restart', 'envsetup-tester.timer'])
            print('Enabled "envsetup-tester.timer" in systemd.')

    # Remove old files
    deprecated_files = (
        '/lib/systemd/system/envsetup-tests.timer',
        '/lib/systemd/system/envsetup-tests.service',
        '/etc/systemd/system/envsetup-tests.timer',
        '/etc/systemd/system/envsetup-tests.service',
        '/etc/systemd/system/ubicast-config.service'
    )
    for path in deprecated_files:
        if os.path.exists(path):
            # Disable service/timer
            name = path.rsplit('/', 1)[-1]
            subprocess.run(['systemctl', 'disable', name])
            subprocess.run(['systemctl', 'stop', name])
            # Remove service/timer
            os.remove(path)
            print('Removed deprecated file: "%s".' % path)
