#!/usr/bin/env bash

RED='\033[0;31m'    # Red color
GREEN='\033[0;32m'  # Green color
ORANGE='\033[0;33m' # Orange color
BLUE='\033[0;34m'   # Blue color
NC='\033[0m'        # Normal color

# Formatting functions
msg() {
    color="${1}"
    msg="${2}"
    date="$(date +'%d/%m/%Y %H:%M:%S')"

    COLOR="${NC}"

    case "${color}" in
        "white")   COLOR="${NC}";;
        "red")     COLOR="${RED}";;
        "green")   COLOR="${GREEN}";;
        "blue")    COLOR="${BLUE}";;
        "orange")  COLOR="${ORANGE}";;
    esac

    while IFS= read -r line;do
        echo -e "${date} - ${COLOR}${line}${NC}"
        echo "${date} - ${line}" >> ${LOG_FILE}
    done <<< "${msg}"

}

# Print the configuration of a distant system
get_system_config() {
    system="${1}"
    name="${2}"

    msg "white" "Getting the system informations on the ${name}"
    cpuinfos=$(ssh -l root ${system} -- "lscpu | grep '^CPU(s)\|Thread(s)\|Core(s)\|Model name\|MHz'")
    raminfos=$(ssh -l root ${system} -- "free -h")

    echo -e "${GREEN}${name} (${system}):${NC}"
    echo "# ${name} (${system}):" >> $SYSINFO_FILE
    echo -e "${BLUE}CPU infos:${NC}"
    echo "## CPU infos:" >> $SYSINFO_FILE
    echo "${cpuinfos}" | tee -a $SYSINFO_FILE
    echo -e "${BLUE}RAM infos:${NC}"
    echo "RAM infos:" >> $SYSINFO_FILE
    echo "${raminfos}" | tee -a $SYSINFO_FILE
    echo | tee -a $SYSINFO_FILE
}

# Network bench tool
get_net_bandwidth() {
    ms_ip="${1}"
    live_ip="${2}"

    msg "white" "Stopping nginx on the live server"
    ssh -l root ${live_ip} -- "systemctl stop nginx"

    msg "white" "Getting the servername of the live server in the nginx config"
    live_dns="$(ssh -l root ${live_ip} -- 'grep -oP "server_name \K[^;]+" /etc/nginx/sites-enabled/live.conf | head -n1')"
    msg "white" "Starting netcat in listening mode on tcp/80 on the live server"
    nc_pid=$(ssh -l root ${live_ip} -- "nc -lp 80 1>/dev/null &")
    msg "white" "Copying 1GB of data to the servername listening netcat on the live server to measure bandwidth"
    dd_infos="$(ssh -l root ${ms_ip} -- "dd if=/dev/zero bs=1M count=1K | nc -q 0 ${live_dns} 80" 2>&1)"

    msg "white" "Restarting nginx on the live server"
    ssh -l root ${live_ip} -- "systemctl start nginx"

    echo -ne "${GREEN}Measured maximal bandwidth from ${ms_ip} to ${live_ip}: ${NC}"
    echo -n "# Measured maximal bandwidth from ${ms_ip} to ${live_ip}: " >> ${SYSINFO_FILE}
    echo "${dd_infos}" | grep -oP "[0-9\.]+ MB\/s" | tee -a ${SYSINFO_FILE}
    echo | tee -a ${SYSINFO_FILE}
}

get_stream_infos() {
    ms_ip="${1}"
    ms_instance="${2}"
    script="/root/envsetup/tools/benchmark/live/resources/get-stream-infos.sh"

    echo -e "${GREEN}Tested stream quality infos: ${NC}"
    echo "# Tested stream quality infos: " >> ${SYSINFO_FILE}
    echo -e "$(ssh -l root ${ms_ip} -- "${script} ${ms_instance}")\n" | tee -a ${SYSINFO_FILE}
}
