#!/usr/bin/env bash

# Global variables
HLS_DIR="${1}"
DURATION="${2}"              # Duration of the checks
EXPECTED_PLAYLISTS_NB="${3}" # Number of playlists

current_iteration=1
failure=0

# While we did not reach the targeted duration
while [[ ${current_iteration} -le ${DURATION} ]]; do
    playlists_ls=$(ls -1 "${HLS_DIR}/"*.m3u8)
    playlists_nb=$(echo "${playlists_ls}" | wc -l)
    # For each m3u8 live playlist
    for playlist in $(ls "${HLS_DIR}/"*.m3u8); do
        playlist_mtime=$(stat -c %Y ${playlist})
        current_time=$(date +%s)
        # If there are more than 4s of difference the check as a failure and print infos
        # We compute the mtime difference with "now" directly in the "if" directive to gain the assignation time
        if [[ $(( current_time - playlist_mtime )) -gt 4 ]]; then
            cat << EOF
$(basename ${playlist}) mtime older than 4s:
 => mtime:           $(date -d @$(${playlist_mtime}))
 => comparison time: $(date -d @$(${current_time}))
EOF

            failure=$(( failure + 1 ))
            break
        fi
    done

    # If we dont have the expected number of playlists, it is a anomaly
    if [[ ${playlists_nb} -ne ${EXPECTED_PLAYLISTS_NB} ]]; then
        echo "Wrong number of playlists, expected ${EXPECTED_PLAYLISTS_NB}, got ${playlists_nb}"
        failure=$(( failure + 1 ))
    fi

    current_iteration=$(( current_iteration + 1 ))
    sleep 1
done

# If there was a failure tagged, stops the script
if [[ ${failure} -ge 1 ]]; then
    echo "${failure} anomalie(s) has been found during the test"

    exit 1
else
    exit 0
fi
